Version 0.7.0
-------------
* Added support for the Woopra service.
* Added chat window text customization to Olark.
* Renamed ``MIXPANEL_TOKEN`` setting to ``MIXPANEL_API_TOKEN`` for
  compatibility with Wes Winham's mixpanel-celery_ package.
* Fixed the ``<script>`` tag for Crazy Egg.

.. _mixpanel-celery: https://github.com/winhamwr/mixpanel-celery

Version 0.6.0
-------------
* Added support for the Reinvigorate service.
* Added support for the Olark service.

Version 0.5.0
-------------
* Split off Geckoboard support into django-geckoboard_.

.. _django-geckoboard: http://pypi.python.org/pypi/django-geckoboard

Version 0.4.0
-------------
* Added support for the Geckoboard service.

Version 0.3.0
-------------
* Added support for the Performable service.

Version 0.2.0
-------------
* Added support for the HubSpot service.
* Added template tags for individual services.

Version 0.1.0
-------------
* First project release.
